/*
 * GNOME hardware sensors panel applet
 * (C) 1999 The Free Software Foundation
 *
 * Displays the state of hardware sensors in your machine.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *                                
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *           
 * Authors: 	Brendon Humphrey (brendy@swipnet.se)
 *
 * This applet is based on the diskusage applet and the 'sensors'
 * application that is included in the lm_sensors package.
 *
 */

#include <stdio.h>
#include <string.h>
#include <gnome.h>

#include "properties.h"
#include "gnomesensors.h"

GtkWidget *properties_dlg = NULL;
GtkWidget *fontsel_dlg = NULL;
sensors_properties temp_props;
sensors_properties *real_props;

/* ==========================================================================
 * load_properties
 * =========================================================================*/
void load_properties( const char *path, sensors_properties *prop )
{
	gnome_config_push_prefix (path);	
	prop->speed	 = gnome_config_get_int("gnome_sensors/speed="DEFAULT_SPEED);
	prop->height 	 = gnome_config_get_int("gnome_sensors/height="DEFAULT_HEIGHT);
	prop->width 	 = gnome_config_get_int("gnome_sensors/width="DEFAULT_WIDTH);
	prop->name_ypos   = gnome_config_get_int("gnome_sensors/name_ypos="DEFAULT_NAME_YPOS);  
	prop->value_ypos  = gnome_config_get_int("gnome_sensors/value_ypos="DEFAULT_VALUE_YPOS);
	prop->units_ypos  = gnome_config_get_int("gnome_sensors/units_ypos="DEFAULT_UNITS_YPOS);
	prop->look	       = gnome_config_get_bool("gnome_sensors/look="DEFAULT_LOOK);
	prop->tcolor	  = gnome_config_get_string ("gnome_sensors/tcolor="DEFAULT_TEXT_RGB);
	prop->default_font = gnome_config_get_string ("gnome_sensors/dfont="DEFAULT_FONT);
	prop->label_font   = gnome_config_get_string ("gnome_sensors/label_font="DEFAULT_LABEL_FONT);
	prop->value_font   = gnome_config_get_string ("gnome_sensors/value_font="DEFAULT_VALUE_FONT);
	prop->units_font   = gnome_config_get_string ("gnome_sensors/units_font="DEFAULT_UNITS_FONT);
	if (prop->tcolor && (strlen(prop->tcolor) < MAX_RGB_STR_LEN))
		prop->tcolor = g_realloc(prop->tcolor, MAX_RGB_STR_LEN+1);
	gnome_config_pop_prefix ();
}

/* ==========================================================================
 * save_properties
 * =========================================================================*/
void save_properties( const char *path, sensors_properties *prop )
{
	gnome_config_push_prefix (path);
	gnome_config_set_string ("gnome_sensors/dfont", prop->default_font);
	gnome_config_set_string ("gnome_sensors/label_font=", prop->label_font);
	gnome_config_set_string ("gnome_sensors/value_font=", prop->value_font);
	gnome_config_set_string ("gnome_sensors/units_font=", prop->units_font);
	gnome_config_set_string ("gnome_sensors/tcolor", prop->tcolor );
	gnome_config_set_int    ("gnome_sensors/speed", prop->speed );
	gnome_config_set_int    ("gnome_sensors/height", prop->height );
	gnome_config_set_int    ("gnome_sensors/width", prop->width );
	gnome_config_set_int    ("gnome_sensors/name_ypos", prop->name_ypos);  
	gnome_config_set_int    ("gnome_sensors/value_ypos", prop->value_ypos);
	gnome_config_set_int    ("gnome_sensors/units_ypos", prop->units_ypos);
	gnome_config_set_bool   ("gnome_sensors/look", prop->look );
	gnome_config_pop_prefix ();
	gnome_config_sync();
	gnome_config_drop_all();
}

